Directive

Struct Directive 

pub struct Directive {
    pub name: String,
    pub arguments: Vec<Arg>,
}
Represent a directive invocation. This combines a directive name (or abbreviation) with the list of actual arguments provided. See [Self.execute()] to actually perform this directive’s action.

Fields

name: String

The directive name.

arguments: Vec<Arg>

The directive arguments.

Implementations

Source

impl Directive

pub fn execute(&self, config: &mut HhhArgs) -> Option<String>

Try to execute the directive. This performs lookup of the directive, where the name is allowed to be an (unambiguous) abbreviation of the directive name.

The return value is None on success and an error message on error.